# -*- coding: utf-8 -*-
"""
This demo provides an illustration on how to read and visualize AOD in
LGHAP dataset and write data into GeoTIFF in MATLAB.

netCDF4 is needed to read netCDF file
You can install this library by command: pip install netCDF4

The demo was prepared with Python3.7.

Last updated: 2021-11-01

"""

# import supporting library
import netCDF4 as nc
import numpy as np
import matplotlib.pyplot as plt
from osgeo import gdal,osr
import re

## (a) read AOD data from NetCDF file
# the nc file to be read
filename = 'LGHAP.AOD.D001.Axxxxxxxx.nc'
f = nc.Dataset(filename)

# extract date from filename
date = re.compile(r'\d{8}').findall(filename)

# read longitude and latitude from NetCDF file
lon = np.array(f['lon'][:])
lat = np.array(f['lat'][:])

# read AOD data
AOD = np.array(f['AOD'][:])

# replace missing value with nan
AOD[AOD==65535] = np.nan

## (b) visualization
# create canvas
fig, ax = plt.subplots(figsize=(17,10))

# plot AOD
im = ax.imshow(np.rot90(AOD,k=1),vmin = 0,vmax = 2,cmap = 'jet',extent = [min(lon),max(lon),min(lat),max(lat)])

# set ticks and label
ax.set_xlabel('Longitude(°)',size=20)
ax.set_ylabel('Latitude(°)',size=20)
plt.xticks(fontsize=20)
plt.yticks(fontsize=20)

# add title
plt.title('Date:'+date[0],size=20)

# add colorbar
fig.subplots_adjust(right=0.9)
position = fig.add_axes([0.90,0.15,0.015,0.70])
cb = fig.colorbar(im,cax=position)
cb.ax.tick_params(labelsize=20)
cb.set_label('AOD',size=20)

# save plot in jpg format with resolution of 300 DPI
plt.savefig('LGHAP.AOD.D001.A'+date[0]+'.jpg',dpi=300)
plt.show()
 
## (c) save as GeoTIFF
# define fillvalue
AOD_tiff = AOD
AOD_tiff[np.isnan(AOD_tiff)] = -999

# write GeoTIFF
driver = gdal.GetDriverByName('GTiff')
dataset = driver.Create('LGHAP.AOD.D001.A'+date[0]+'.tif',len(lon),len(lat),1,gdal.GDT_Float64)
dataset.SetGeoTransform([min(lon),0.01,0,max(lat),0,-0.01])
sr = osr.SpatialReference()
sr.SetWellKnownGeogCS('WGS84')
dataset.SetProjection(sr.ExportToWkt())
dataset.GetRasterBand(1).WriteArray(np.rot90(AOD_tiff,k=1))

# release memory
del dataset
f.close()
