% This demo provides an illustration on how to read and visualize PM10 in
% LGHAP dataset and write data into GeoTIFF in MATLAB.
%
% The demo was prepared with MATLAB R2020b.
%
% Last updated: 2021-11-01

%% (a) read PM10 data from NetCDF file

% the nc file to be read
filename = 'LGHAP.PM10.D001.Axxxxxxxx.nc';

% read longitude and latitude from NetCDF file
lon = ncread(filename,'lon');
lat = ncread(filename,'lat');

% read PM10 data
PM10 = ncread(filename,'PM10');

%% (b) visualization

% create georeference struct to map PM10 data on projected datum
R = georefcells([14.995,56.005],[70.995,139.005],[4100,6800]);
latlim = R.LatitudeLimits;
lonlim = R.LongitudeLimits;

% load coastlines
load coastlines

% plot data
pos = get(0,'ScreenSize');

figure('color','w','position',[50,50,round(pos(3)*0.5),round(pos(4)*0.5)]);

worldmap(latlim,lonlim)

% plot coastline
geoshow(coastlat,coastlon,'Color','k')

% plot PM10
geoshow(PM10,R,'DisplayType','surface');

% set colormap limits
caxis([0,300]);

% set colors used to map data
colormap('Jet');

% add colorbar
h = colorbar();
h.Label.String = 'PM10';
h.FontSize = 14;
setm(gca,'FontSize',14);

% add title to the plot 
title(['Date',string(regexp(filename,'\d{8}','match'))],'FontSize',14);

% save plot in jpg format with resolution of 300 DPI
savename = ['LGHAP.PM10.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.jpg'];
print(savename,'-djpeg','-r300');

%% (c) save as GeoTIFF

% define fillvalue
Fillvalue = -999;
PM10_tiff = PM10;
PM10_tiff(isnan(PM10_tiff)) = Fillvalue;

% write GeoTIFF
savename = ['LGHAP.PM10.D001.A' char(string(regexp(filename,'\d{8}','match'))) '.tif'];
geotiffwrite(savename,PM10_tiff,R);
